<?php

namespace Drupal\ocr_image\Plugin\Field;

use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Class trait all languages for tesseract.
 */
class TesseractLanguages {

  /**
   * Convert drupal language iso to tesseract lang.
   *
   * @return string
   *   Return code language tesseract.
   */
  public static function tesseractConvertLang(): string {
    $languages = [
      'aa' => 'afr',
      'am' => 'amh',
      'ar' => 'ara',
      'as' => 'asm',
      'az' => 'aze',
      'be' => 'bel',
      'bn' => 'ben',
      'bo' => 'bod',
      'bs' => 'bos',
      'br' => 'bre',
      'bg' => 'bul',
      'ca' => 'cat',
      'cs' => 'ces',
      'zh-hans' => 'chi_sim',
      'zh-hant' => 'chi_tra',
      'co' => 'cos',
      'cy' => 'cym',
      'da' => 'dan',
      'de' => 'deu',
      'dz' => 'dzo',
      'el' => 'ell',
      'en' => 'eng',
      'en-gb' => 'enm',
      'eo' => 'epo',
      'et' => 'est',
      'eu' => 'eus',
      'fo' => 'fao',
      'fa' => 'fas',
      'fi' => 'fin',
      'fr' => 'fra',
      'fy' => 'fry',
      'gd' => 'gla',
      'ga' => 'gle',
      'gl' => 'glg',
      'gu' => 'guj',
      'ht' => 'hat',
      'he' => 'heb',
      'hi' => 'hin',
      'hr' => 'hrv',
      'hu' => 'hun',
      'hy' => 'hye',
      'iu' => 'iku',
      'id' => 'ind',
      'is' => 'isl',
      'it' => 'ita',
      'jv' => 'jav',
      'ja' => 'jpn',
      'kn' => 'kan',
      'ka' => 'kat',
      'kk' => 'kaz',
      'km' => 'khm',
      'ky' => 'kir',
      'ko' => 'kor',
      'ku' => 'kur',
      'lo' => 'lao',
      'la' => 'lat',
      'lv' => 'lav',
      'lt' => 'lit',
      'ml' => 'mal',
      'mr' => 'mar',
      'mk' => 'mkd',
      'mt' => 'mlt',
      'mn' => 'mon',
      'ms' => 'msa',
      'my' => 'mya',
      'ne' => 'nep',
      'no' => 'nor',
      'oc' => 'oci',
      'or' => 'ori',
      'pa' => 'pan',
      'pl' => 'pol',
      'pt' => 'por',
      'ps' => 'pus',
      'qu' => 'que',
      'ro' => 'ron',
      'ru' => 'rus',
      'sa' => 'san',
      'si' => 'sin',
      'sk' => 'slk',
      'sl' => 'slv',
      'es' => 'spa',
      'sq' => 'sqi',
      'sr' => 'srp',
      'su' => 'sun',
      'sw' => 'swa',
      'sv' => 'swe',
      'sy' => 'syr',
      'ta' => 'tam',
      'te' => 'tel',
      'tg' => 'tgk',
      'tl' => 'tgl',
      'th' => 'tha',
      'ti' => 'tir',
      'to' => 'ton',
      'tr' => 'tur',
      'ug' => 'uig',
      'uk' => 'ukr',
      'ur' => 'urd',
      'uz' => 'uzb',
      'vi' => 'vie',
      'yi' => 'yid',
      'yo' => 'yor',
    ];
    $isoLang = \Drupal::languageManager()->getCurrentLanguage()->getId();
    return $languages[$isoLang] ?? 'eng';
  }

  /**
   * Option languages for Tesseract.
   */
  public static function tesseractLangues(): array {
    return [
      'afr' => new TranslatableMarkup('Afrikaans'),
      'amh' => new TranslatableMarkup('Amharic'),
      'ara' => new TranslatableMarkup('Arabic'),
      'asm' => new TranslatableMarkup('Assamese'),
      'aze' => new TranslatableMarkup('Azerbaijani'),
      'aze_cyrl' => new TranslatableMarkup('Azerbaijani - Cyrilic'),
      'bel' => new TranslatableMarkup('Belarusian'),
      'ben' => new TranslatableMarkup('Bengali'),
      'bod' => new TranslatableMarkup('Tibetan'),
      'bos' => new TranslatableMarkup('Bosnian'),
      'bre' => new TranslatableMarkup('Breton'),
      'bul' => new TranslatableMarkup('Bulgarian'),
      'cat' => new TranslatableMarkup('Catalan; Valencian'),
      'ceb' => new TranslatableMarkup('Cebuano'),
      'ces' => new TranslatableMarkup('Czech'),
      'chi_sim' => new TranslatableMarkup('Chinese - Simplified'),
      'chi_tra' => new TranslatableMarkup('Chinese - Traditional'),
      'chr' => new TranslatableMarkup('Cherokee'),
      'cos' => new TranslatableMarkup('Corsican'),
      'cym' => new TranslatableMarkup('Welsh'),
      'dan' => new TranslatableMarkup('Danish'),
      'dan_frak' => new TranslatableMarkup('Danish - Fraktur (contrib)'),
      'deu' => new TranslatableMarkup('German'),
      'deu_frak' => new TranslatableMarkup('German - Fraktur (contrib)'),
      'dzo' => new TranslatableMarkup('Dzongkha'),
      'ell' => new TranslatableMarkup('Greek, Modern (1453-)'),
      'eng' => new TranslatableMarkup('English'),
      'enm' => new TranslatableMarkup('English, Middle (1100-1500)'),
      'epo' => new TranslatableMarkup('Esperanto'),
      'equ' => new TranslatableMarkup('Math / equation detection module'),
      'est' => new TranslatableMarkup('Estonian'),
      'eus' => new TranslatableMarkup('Basque'),
      'fao' => new TranslatableMarkup('Faroese'),
      'fas' => new TranslatableMarkup('Persian'),
      'fil' => new TranslatableMarkup('Filipino (old - Tagalog)'),
      'fin' => new TranslatableMarkup('Finnish'),
      'fra' => new TranslatableMarkup('French'),
      'frk' => new TranslatableMarkup('German - Fraktur'),
      'frm' => new TranslatableMarkup('French, Middle (ca.1400-1600)'),
      'fry' => new TranslatableMarkup('Western Frisian'),
      'gla' => new TranslatableMarkup('Scottish Gaelic'),
      'gle' => new TranslatableMarkup('Irish'),
      'glg' => new TranslatableMarkup('Galician'),
      'grc' => new TranslatableMarkup('Greek, Ancient (to 1453) (contrib)'),
      'guj' => new TranslatableMarkup('Gujarati'),
      'hat' => new TranslatableMarkup('Haitian; Haitian Creole'),
      'heb' => new TranslatableMarkup('Hebrew'),
      'hin' => new TranslatableMarkup('Hindi'),
      'hrv' => new TranslatableMarkup('Croatian'),
      'hun' => new TranslatableMarkup('Hungarian'),
      'hye' => new TranslatableMarkup('Armenian'),
      'iku' => new TranslatableMarkup('Inuktitut'),
      'ind' => new TranslatableMarkup('Indonesian'),
      'isl' => new TranslatableMarkup('Icelandic'),
      'ita' => new TranslatableMarkup('Italian'),
      'ita_old' => new TranslatableMarkup('Italian - Old'),
      'jav' => new TranslatableMarkup('Javanese'),
      'jpn' => new TranslatableMarkup('Japanese'),
      'kan' => new TranslatableMarkup('Kannada'),
      'kat' => new TranslatableMarkup('Georgian'),
      'kat_old' => new TranslatableMarkup('Georgian - Old'),
      'kaz' => new TranslatableMarkup('Kazakh'),
      'khm' => new TranslatableMarkup('Central Khmer'),
      'kir' => new TranslatableMarkup('Kirghiz; Kyrgyz'),
      'kmr' => new TranslatableMarkup('Kurmanji (Kurdish - Latin Script)'),
      'kor' => new TranslatableMarkup('Korean'),
      'kor_vert' => new TranslatableMarkup('Korean (vertical)'),
      'kur' => new TranslatableMarkup('Kurdish (Arabic Script)'),
      'lao' => new TranslatableMarkup('Lao'),
      'lat' => new TranslatableMarkup('Latin'),
      'lav' => new TranslatableMarkup('Latvian'),
      'lit' => new TranslatableMarkup('Lithuanian'),
      'ltz' => new TranslatableMarkup('Luxembourgish'),
      'mal' => new TranslatableMarkup('Malayalam'),
      'mar' => new TranslatableMarkup('Marathi'),
      'mkd' => new TranslatableMarkup('Macedonian'),
      'mlt' => new TranslatableMarkup('Maltese'),
      'mon' => new TranslatableMarkup('Mongolian'),
      'mri' => new TranslatableMarkup('Maori'),
      'msa' => new TranslatableMarkup('Malay'),
      'mya' => new TranslatableMarkup('Burmese'),
      'nep' => new TranslatableMarkup('Nepali'),
      'nld' => new TranslatableMarkup('Dutch; Flemish'),
      'nor' => new TranslatableMarkup('Norwegian'),
      'oci' => new TranslatableMarkup('Occitan (post 1500)'),
      'ori' => new TranslatableMarkup('Oriya'),
      'osd' => new TranslatableMarkup('Orientation and script detection module'),
      'pan' => new TranslatableMarkup('Panjabi; Punjabi'),
      'pol' => new TranslatableMarkup('Polish'),
      'por' => new TranslatableMarkup('Portuguese'),
      'pus' => new TranslatableMarkup('Pushto; Pashto'),
      'que' => new TranslatableMarkup('Quechua'),
      'ron' => new TranslatableMarkup('Romanian; Moldavian; Moldovan'),
      'rus' => new TranslatableMarkup('Russian'),
      'san' => new TranslatableMarkup('Sanskrit'),
      'sin' => new TranslatableMarkup('Sinhala; Sinhalese'),
      'slk' => new TranslatableMarkup('Slovak'),
      'slk_frak' => new TranslatableMarkup('Slovak - Fraktur (contrib)'),
      'slv' => new TranslatableMarkup('Slovenian'),
      'snd' => new TranslatableMarkup('Sindhi'),
      'spa' => new TranslatableMarkup('Spanish; Castilian'),
      'spa_old' => new TranslatableMarkup('Spanish; Castilian - Old'),
      'sqi' => new TranslatableMarkup('Albanian'),
      'srp' => new TranslatableMarkup('Serbian'),
      'srp_latn' => new TranslatableMarkup('Serbian - Latin'),
      'sun' => new TranslatableMarkup('Sundanese'),
      'swa' => new TranslatableMarkup('Swahili'),
      'swe' => new TranslatableMarkup('Swedish'),
      'syr' => new TranslatableMarkup('Syriac'),
      'tam' => new TranslatableMarkup('Tamil'),
      'tat' => new TranslatableMarkup('Tatar'),
      'tel' => new TranslatableMarkup('Telugu'),
      'tgk' => new TranslatableMarkup('Tajik'),
      'tgl' => new TranslatableMarkup('Tagalog (new - Filipino)'),
      'tha' => new TranslatableMarkup('Thai'),
      'tir' => new TranslatableMarkup('Tigrinya'),
      'ton' => new TranslatableMarkup('Tonga'),
      'tur' => new TranslatableMarkup('Turkish'),
      'uig' => new TranslatableMarkup('Uighur; Uyghur'),
      'ukr' => new TranslatableMarkup('Ukrainian'),
      'urd' => new TranslatableMarkup('Urdu'),
      'uzb' => new TranslatableMarkup('Uzbek'),
      'uzb_cyrl' => new TranslatableMarkup('Uzbek - Cyrilic'),
      'vie' => new TranslatableMarkup('Vietnamese'),
      'yid' => new TranslatableMarkup('Yiddish'),
      'yor' => new TranslatableMarkup('Yoruba'),
    ];
  }

}
